@@ -20,6 +20,7 @@ from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .literals import (
+    EfsInTransitEncryptionType,
     HdfsAuthenticationTypeType,
     ObjectStorageServerProtocolType,
     S3StorageClassType,
@@ -35,6 +36,7 @@ from .type_defs import (
     CreateAgentResponseTypeDef,
     CreateLocationEfsResponseTypeDef,
     CreateLocationFsxLustreResponseTypeDef,
+    CreateLocationFsxOntapResponseTypeDef,
     CreateLocationFsxOpenZfsResponseTypeDef,
     CreateLocationFsxWindowsResponseTypeDef,
     CreateLocationHdfsResponseTypeDef,
@@ -46,6 +48,7 @@ from .type_defs import (
     DescribeAgentResponseTypeDef,
     DescribeLocationEfsResponseTypeDef,
     DescribeLocationFsxLustreResponseTypeDef,
+    DescribeLocationFsxOntapResponseTypeDef,
     DescribeLocationFsxOpenZfsResponseTypeDef,
     DescribeLocationFsxWindowsResponseTypeDef,
     DescribeLocationHdfsResponseTypeDef,
@@ -133,12 +136,20 @@ class DataSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#cancel_task_execution)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#close)
+        """
+
     def create_agent(
         self,
         *,
         ActivationKey: str,
         AgentName: str = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...,
         VpcEndpointId: str = ...,
         SubnetArns: Sequence[str] = ...,
         SecurityGroupArns: Sequence[str] = ...
@@ -154,12 +165,16 @@ class DataSyncClient(BaseClient):
         self,
         *,
         EfsFilesystemArn: str,
-        Ec2Config: "Ec2ConfigTypeDef",
+        Ec2Config: Ec2ConfigTypeDef,
         Subdirectory: str = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...,
+        AccessPointArn: str = ...,
+        FileSystemAccessRoleArn: str = ...,
+        InTransitEncryption: EfsInTransitEncryptionType = ...
     ) -> CreateLocationEfsResponseTypeDef:
         """
-        Creates an endpoint for an Amazon EFS file system.
+        Creates an endpoint for an Amazon EFS file system that DataSync can access for a
+        transfer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_efs)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_efs)
@@ -171,7 +186,7 @@ class DataSyncClient(BaseClient):
         FsxFilesystemArn: str,
         SecurityGroupArns: Sequence[str],
         Subdirectory: str = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationFsxLustreResponseTypeDef:
         """
         Creates an endpoint for an Amazon FSx for Lustre file system.
@@ -180,14 +195,31 @@ class DataSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_lustre)
         """
 
+    def create_location_fsx_ontap(
+        self,
+        *,
+        Protocol: FsxProtocolTypeDef,
+        SecurityGroupArns: Sequence[str],
+        StorageVirtualMachineArn: str,
+        Subdirectory: str = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...
+    ) -> CreateLocationFsxOntapResponseTypeDef:
+        """
+        Creates an endpoint for an Amazon FSx for NetApp ONTAP file system that DataSync
+        can access for a transfer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_fsx_ontap)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_fsx_ontap)
+        """
+
     def create_location_fsx_open_zfs(
         self,
         *,
         FsxFilesystemArn: str,
-        Protocol: "FsxProtocolTypeDef",
+        Protocol: FsxProtocolTypeDef,
         SecurityGroupArns: Sequence[str],
         Subdirectory: str = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationFsxOpenZfsResponseTypeDef:
         """
         Creates an endpoint for an Amazon FSx for OpenZFS file system.
@@ -204,7 +236,7 @@ class DataSyncClient(BaseClient):
         User: str,
         Password: str,
         Subdirectory: str = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...,
         Domain: str = ...
     ) -> CreateLocationFsxWindowsResponseTypeDef:
         """
@@ -217,19 +249,19 @@ class DataSyncClient(BaseClient):
     def create_location_hdfs(
         self,
         *,
-        NameNodes: Sequence["HdfsNameNodeTypeDef"],
+        NameNodes: Sequence[HdfsNameNodeTypeDef],
         AuthenticationType: HdfsAuthenticationTypeType,
         AgentArns: Sequence[str],
         Subdirectory: str = ...,
         BlockSize: int = ...,
         ReplicationFactor: int = ...,
         KmsKeyProviderUri: str = ...,
-        QopConfiguration: "QopConfigurationTypeDef" = ...,
+        QopConfiguration: QopConfigurationTypeDef = ...,
         SimpleUser: str = ...,
         KerberosPrincipal: str = ...,
         KerberosKeytab: Union[str, bytes, IO[Any], StreamingBody] = ...,
         KerberosKrb5Conf: Union[str, bytes, IO[Any], StreamingBody] = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationHdfsResponseTypeDef:
         """
         Creates an endpoint for a Hadoop Distributed File System (HDFS).
@@ -243,9 +275,9 @@ class DataSyncClient(BaseClient):
         *,
         Subdirectory: str,
         ServerHostname: str,
-        OnPremConfig: "OnPremConfigTypeDef",
-        MountOptions: "NfsMountOptionsTypeDef" = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        OnPremConfig: OnPremConfigTypeDef,
+        MountOptions: NfsMountOptionsTypeDef = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationNfsResponseTypeDef:
         """
         Defines a file system on a Network File System (NFS) server that can be read
@@ -266,10 +298,11 @@ class DataSyncClient(BaseClient):
         Subdirectory: str = ...,
         AccessKey: str = ...,
         SecretKey: str = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationObjectStorageResponseTypeDef:
         """
-        Creates an endpoint for a self-managed object storage bucket.
+        Creates an endpoint for an object storage system that DataSync can access for a
+        transfer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_location_object_storage)
@@ -279,11 +312,11 @@ class DataSyncClient(BaseClient):
         self,
         *,
         S3BucketArn: str,
-        S3Config: "S3ConfigTypeDef",
+        S3Config: S3ConfigTypeDef,
         Subdirectory: str = ...,
         S3StorageClass: S3StorageClassType = ...,
         AgentArns: Sequence[str] = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationS3ResponseTypeDef:
         """
         Creates an endpoint for an Amazon S3 bucket.
@@ -301,8 +334,8 @@ class DataSyncClient(BaseClient):
         Password: str,
         AgentArns: Sequence[str],
         Domain: str = ...,
-        MountOptions: "SmbMountOptionsTypeDef" = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...
+        MountOptions: SmbMountOptionsTypeDef = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...
     ) -> CreateLocationSmbResponseTypeDef:
         """
         Defines a file system on a Server Message Block (SMB) server that can be read
@@ -319,14 +352,14 @@ class DataSyncClient(BaseClient):
         DestinationLocationArn: str,
         CloudWatchLogGroupArn: str = ...,
         Name: str = ...,
-        Options: "OptionsTypeDef" = ...,
-        Excludes: Sequence["FilterRuleTypeDef"] = ...,
-        Schedule: "TaskScheduleTypeDef" = ...,
-        Tags: Sequence["TagListEntryTypeDef"] = ...,
-        Includes: Sequence["FilterRuleTypeDef"] = ...
+        Options: OptionsTypeDef = ...,
+        Excludes: Sequence[FilterRuleTypeDef] = ...,
+        Schedule: TaskScheduleTypeDef = ...,
+        Tags: Sequence[TagListEntryTypeDef] = ...,
+        Includes: Sequence[FilterRuleTypeDef] = ...
     ) -> CreateTaskResponseTypeDef:
         """
-        Creates a task.
+        Configures a task, which defines where and how DataSync transfers your data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.create_task)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#create_task)
@@ -367,7 +400,7 @@ class DataSyncClient(BaseClient):
 
     def describe_location_efs(self, *, LocationArn: str) -> DescribeLocationEfsResponseTypeDef:
         """
-        Returns metadata, such as the path information about an Amazon EFS location.
+        Returns metadata about your DataSync location for an Amazon EFS file system.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_efs)
@@ -384,6 +417,17 @@ class DataSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_lustre)
         """
 
+    def describe_location_fsx_ontap(
+        self, *, LocationArn: str
+    ) -> DescribeLocationFsxOntapResponseTypeDef:
+        """
+        Provides details about how an DataSync location for an Amazon FSx for NetApp
+        ONTAP file system is configured.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_fsx_ontap)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_fsx_ontap)
+        """
+
     def describe_location_fsx_open_zfs(
         self, *, LocationArn: str
     ) -> DescribeLocationFsxOpenZfsResponseTypeDef:
@@ -427,7 +471,7 @@ class DataSyncClient(BaseClient):
         self, *, LocationArn: str
     ) -> DescribeLocationObjectStorageResponseTypeDef:
         """
-        Returns metadata about a self-managed object storage server location.
+        Returns metadata about your DataSync location for an object storage system.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#describe_location_object_storage)
@@ -497,7 +541,7 @@ class DataSyncClient(BaseClient):
         *,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: Sequence["LocationFilterTypeDef"] = ...
+        Filters: Sequence[LocationFilterTypeDef] = ...
     ) -> ListLocationsResponseTypeDef:
         """
         Returns a list of source and destination locations.
@@ -531,10 +575,10 @@ class DataSyncClient(BaseClient):
         *,
         MaxResults: int = ...,
         NextToken: str = ...,
-        Filters: Sequence["TaskFilterTypeDef"] = ...
+        Filters: Sequence[TaskFilterTypeDef] = ...
     ) -> ListTasksResponseTypeDef:
         """
-        Returns a list of all the tasks.
+        Returns a list of the DataSync tasks you created.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Client.list_tasks)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/client/#list_tasks)
@@ -544,9 +588,9 @@ class DataSyncClient(BaseClient):
         self,
         *,
         TaskArn: str,
-        OverrideOptions: "OptionsTypeDef" = ...,
-        Includes: Sequence["FilterRuleTypeDef"] = ...,
-        Excludes: Sequence["FilterRuleTypeDef"] = ...
+        OverrideOptions: OptionsTypeDef = ...,
+        Includes: Sequence[FilterRuleTypeDef] = ...,
+        Excludes: Sequence[FilterRuleTypeDef] = ...
     ) -> StartTaskExecutionResponseTypeDef:
         """
         Starts a specific invocation of a task.
@@ -556,7 +600,7 @@ class DataSyncClient(BaseClient):
         """
 
     def tag_resource(
-        self, *, ResourceArn: str, Tags: Sequence["TagListEntryTypeDef"]
+        self, *, ResourceArn: str, Tags: Sequence[TagListEntryTypeDef]
     ) -> Dict[str, Any]:
         """
         Applies a key-value pair to an Amazon Web Services resource.
@@ -586,11 +630,11 @@ class DataSyncClient(BaseClient):
         *,
         LocationArn: str,
         Subdirectory: str = ...,
-        NameNodes: Sequence["HdfsNameNodeTypeDef"] = ...,
+        NameNodes: Sequence[HdfsNameNodeTypeDef] = ...,
         BlockSize: int = ...,
         ReplicationFactor: int = ...,
         KmsKeyProviderUri: str = ...,
-        QopConfiguration: "QopConfigurationTypeDef" = ...,
+        QopConfiguration: QopConfigurationTypeDef = ...,
         AuthenticationType: HdfsAuthenticationTypeType = ...,
         SimpleUser: str = ...,
         KerberosPrincipal: str = ...,
@@ -611,8 +655,8 @@ class DataSyncClient(BaseClient):
         *,
         LocationArn: str,
         Subdirectory: str = ...,
-        OnPremConfig: "OnPremConfigTypeDef" = ...,
-        MountOptions: "NfsMountOptionsTypeDef" = ...
+        OnPremConfig: OnPremConfigTypeDef = ...,
+        MountOptions: NfsMountOptionsTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates some of the parameters of a previously created location for Network File
@@ -650,7 +694,7 @@ class DataSyncClient(BaseClient):
         Domain: str = ...,
         Password: str = ...,
         AgentArns: Sequence[str] = ...,
-        MountOptions: "SmbMountOptionsTypeDef" = ...
+        MountOptions: SmbMountOptionsTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Updates some of the parameters of a previously created location for Server
@@ -664,12 +708,12 @@ class DataSyncClient(BaseClient):
         self,
         *,
         TaskArn: str,
-        Options: "OptionsTypeDef" = ...,
-        Excludes: Sequence["FilterRuleTypeDef"] = ...,
-        Schedule: "TaskScheduleTypeDef" = ...,
+        Options: OptionsTypeDef = ...,
+        Excludes: Sequence[FilterRuleTypeDef] = ...,
+        Schedule: TaskScheduleTypeDef = ...,
         Name: str = ...,
         CloudWatchLogGroupArn: str = ...,
-        Includes: Sequence["FilterRuleTypeDef"] = ...
+        Includes: Sequence[FilterRuleTypeDef] = ...
     ) -> Dict[str, Any]:
         """
         Updates the metadata associated with a task.
@@ -679,7 +723,7 @@ class DataSyncClient(BaseClient):
         """
 
     def update_task_execution(
-        self, *, TaskExecutionArn: str, Options: "OptionsTypeDef"
+        self, *, TaskExecutionArn: str, Options: OptionsTypeDef
     ) -> Dict[str, Any]:
         """
         Updates execution of a task.
