@@ -29,8 +29,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListAgentsResponseTypeDef,
@@ -62,14 +61,14 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListAgentsPaginator(Boto3Paginator):
+class ListAgentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListAgents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators/#listagentspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAgentsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
@@ -77,7 +76,7 @@ class ListAgentsPaginator(Boto3Paginator):
         """
 
 
-class ListLocationsPaginator(Boto3Paginator):
+class ListLocationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListLocations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators/#listlocationspaginator)
@@ -86,8 +85,8 @@ class ListLocationsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["LocationFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[LocationFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListLocationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
@@ -95,14 +94,14 @@ class ListLocationsPaginator(Boto3Paginator):
         """
 
 
-class ListTagsForResourcePaginator(Boto3Paginator):
+class ListTagsForResourcePaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators/#listtagsforresourcepaginator)
     """
 
     def paginate(
-        self, *, ResourceArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTagsForResourceResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
@@ -110,14 +109,14 @@ class ListTagsForResourcePaginator(Boto3Paginator):
         """
 
 
-class ListTaskExecutionsPaginator(Boto3Paginator):
+class ListTaskExecutionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators/#listtaskexecutionspaginator)
     """
 
     def paginate(
-        self, *, TaskArn: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, TaskArn: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTaskExecutionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
@@ -125,7 +124,7 @@ class ListTaskExecutionsPaginator(Boto3Paginator):
         """
 
 
-class ListTasksPaginator(Boto3Paginator):
+class ListTasksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListTasks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators/#listtaskspaginator)
@@ -134,8 +133,8 @@ class ListTasksPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: Sequence["TaskFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: Sequence[TaskFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTasksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
